@@ -3,6 +3,7 @@
 namespace Cms\Search\Campsite;
 
 use Cms\LinkResource\LinkResourcePrefsIdentifier;
+use Cms\Model\Campsite\CampsiteState;
 use Cms\Model\Campsite\Feature\FeatureCode;
 use Cms\Search\ElasticQueryBuilderInterface;
 use Cms\Search\ElasticQueryBuilderTrait;
@@ -16,50 +17,49 @@ use function Cms\Utils\geo_diagonal;
  */
 class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
 {
-
     use ElasticQueryBuilderTrait;
 
     /** Aggregat sur geo division */
-    const AGG_GEO_DIVISION = 'divisionSuggest';
+    public const AGG_GEO_DIVISION = 'divisionSuggest';
 
     /** Aggregat sur geo address */
-    const AGG_ADDR_CITY = 'citySuggest';
+    public const AGG_ADDR_CITY = 'citySuggest';
 
     /** Aggregat sur geo address */
-    const AGG_GEO_ADMIN = 'regionSuggest';
+    public const AGG_GEO_ADMIN = 'regionSuggest';
 
     /** Aggregat sur les thematics */
-    const AGG_THEMATICS = 'thematicSuggest';
+    public const AGG_THEMATICS = 'thematicSuggest';
 
     /** Aggregat sur les campings ids */
-    const AGG_CAMPSITES = 'campsiteSuggest';
+    public const AGG_CAMPSITES = 'campsiteSuggest';
 
     /** Aggregat sur le nombre total d'emplacement */
-    const AGG_TOTAL_EMP = 'totalempSuggest';
+    public const AGG_TOTAL_EMP = 'totalempSuggest';
 
     /** Aggregat sur le classement (etoiles) */
-    const AGG_CLASSMNT = 'classemntSuggest';
+    public const AGG_CLASSMNT = 'classemntSuggest';
 
     /** Aggregat sur les camping avec piscine */
-    const AGG_POOL = 'poolMetric';
+    public const AGG_POOL = 'poolMetric';
 
     /** Aggretat sur les camping avec une feature */
-    const AGG_COUNT_FEATURE = 'featureMetric';
+    public const AGG_COUNT_FEATURE = 'featureMetric';
 
     /** Aggretat sur les camping avec un produit */
-    const AGG_COUNT_PRODUCT = 'productMetric';
+    public const AGG_COUNT_PRODUCT = 'productMetric';
 
     /** Aggretat sur la somme des quantité d'un produit */
-    const AGG_SUM_PRODUCT = 'productSum';
+    public const AGG_SUM_PRODUCT = 'productSum';
 
     /** Aggregat sur les pays */
-    const AGG_GEO_COUNTRY = 'countrySuggest';
+    public const AGG_GEO_COUNTRY = 'countrySuggest';
 
     /** Geo zoom (precision) */
-    const AGG_GEO_ZOOM = 'geoZoom';
+    public const AGG_GEO_ZOOM = 'geoZoom';
 
     /** Geo Viewport */
-    const AGG_GEO_VIEWPORT = 'geoViewport';
+    public const AGG_GEO_VIEWPORT = 'geoViewport';
 
 
     /** @var \Cms\Search\Campsite\CampsiteSearchFragmentFactory */
@@ -93,6 +93,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
         $this->filters['cityName'] = null;
         $this->filters['excludeCityId'] = null;
         $this->filters['features'] = null;
+        $this->filters['productIds'] = null;
         $this->filters['campsiteIds'] = null;
         $this->filters['campsiteIdsWithTh'] = null;
         $this->filters['thematicIds'] = null;
@@ -242,6 +243,17 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
         return $this;
     }
 
+    /**
+     * @param array $productIds
+     * @param float|null $boost
+     * @return $this
+     */
+    public function hasProducts(array $productIds, float $boost = null)
+    {
+        $this->filters['productIds'] = [$boost, $productIds];
+        return $this;
+    }
+
     /**
      * @param string $codeParent
      * @return $this
@@ -393,8 +405,8 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
         // finalisation du builder (on prepare les deux pour le zoom automatique si besoin)
         $this->addFacet(
             static::AGG_GEO_ZOOM,
-            [$precision,],
-            [$boundingFilter,]
+            [$precision],
+            [$boundingFilter]
         );
         if ($addInFilter === true) {
             $this->setAdditionalFilters([
@@ -504,7 +516,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
                 'terms' => [
                     'size' => 100,
                     'field' => 'campsite_thematics',
-                    'order' => ['_count' => 'desc',],
+                    'order' => ['_count' => 'desc'],
                 ],
                 'aggs' => [
                     'campsites' => [
@@ -691,7 +703,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
                             'terms' => [
                                 'size' => $this->aggsSize,
                                 'field' => $nestedPath . '.value',
-                                'order' => ['_count' => 'desc',],
+                                'order' => ['_count' => 'desc'],
                             ],
                         ],
                     ],
@@ -760,7 +772,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
 
         // recherche uniquement sur la division geographique
         if (isset($this->aggs[self::AGG_GEO_ADMIN])) {
-            $searchQuery = ['match_all' => (object)[],];
+            $searchQuery = ['match_all' => (object)[]];
             $nestedPath = $this->fragmentFactory->admin_nested_path;
             if (!empty($this->aggs[self::AGG_GEO_ADMIN])
                 && !\is_bool($this->aggs[self::AGG_GEO_ADMIN])
@@ -780,14 +792,14 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
                         'terms' => [
                             'size' => 300,
                             'field' => $nestedPath . '.id',
-                            'order' => ['_count' => 'desc',],
+                            'order' => ['_count' => 'desc'],
                         ],
                     ],
                     self::AGG_GEO_ADMIN . '_parent' => [
                         'terms' => [
                             'size' => 300,
                             'field' => $nestedPath . '.parent_id',
-                            'order' => ['_count' => 'desc',],
+                            'order' => ['_count' => 'desc'],
                         ],
                     ],
                 ]
@@ -796,7 +808,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
 
         // recherche uniquement sur la division geographique
         if (isset($this->aggs[self::AGG_GEO_DIVISION])) {
-            $searchQuery = ['match_all' => (object)[],];
+            $searchQuery = ['match_all' => (object)[]];
             if (!empty($this->aggs[self::AGG_GEO_DIVISION])) {
                 $searchQuery = $this->fragmentFactory->getDivisionSearchQuery(
                     $this->language,
@@ -812,7 +824,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
                         'terms' => [
                             'size' => 300,
                             'field' => $nestedPath . '.id',
-                            'order' => ['_count' => 'desc',],
+                            'order' => ['_count' => 'desc'],
                         ],
                     ],
                 ]
@@ -842,7 +854,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
                         'terms' => [
                             'size' => 40000,
                             'field' => $nestedPath . '.city_geodata_id',
-                            'order' => ['_count' => 'desc',],
+                            'order' => ['_count' => 'desc'],
                         ],
                     ],
                 ]
@@ -864,7 +876,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
                         'terms' => [
                             'size' => 210,
                             'field' => $nestedPath . '.country_code',
-                            'order' => ['_count' => 'desc',],
+                            'order' => ['_count' => 'desc'],
                         ],
                     ],
                 ]
@@ -920,6 +932,19 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
             $queryParams['bool']['filter'][] = [
                 'term' => ['state' => $this->filters['state']],
             ];
+            if ($this->filters['state'] === CampsiteState::ONLINE) {
+                $queryParams['bool']['filter'][] = [
+                    'bool' => [
+                        'must_not' => [
+                            [
+                                'term' => [
+                                    'campsite_accept_vac' => false,
+                                ],
+                            ],
+                        ],
+                    ],
+                ];
+            }
         }
         if ($this->filters['types']) {
             $queryParams['bool']['filter'][] = [
@@ -938,7 +963,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
 
         // ajout du filtre sur les features
         if ($this->filters['features']) {
-            list($featureBoost, $features) = $this->filters['features'];
+            [$featureBoost, $features] = $this->filters['features'];
             $termsQuery = $this->getTermsQuery(
                 'features.feature_code',
                 $features,
@@ -953,6 +978,24 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
             }
         }
 
+        // ajout du filtre sur les produits
+        if ($this->filters['productIds']) {
+            [$productBoost, $productIds] = $this->filters['productIds'];
+            $termsQuery = $this->getTermsQuery(
+                'campsite_products.id',
+                $productIds,
+                $productBoost
+            );
+
+            if (!$productBoost) {
+                $queryParams['bool']['filter'][] = $termsQuery;
+            } elseif ($productBoost > 0) {
+                $queryParams['bool']['should'][] = $termsQuery;
+            } else {
+                $queryParams['bool']['must_not'][] = $termsQuery;
+            }
+        }
+
         // ajout du filtre sur les id de camping avec thematic
         if ($this->filters['campsiteIdsWithTh']) {
             $boolQuery[] = $this->getTermsQuery(
@@ -1010,7 +1053,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
 
         // ajout du filtre sur les id de camping
         if ($this->filters['campsiteIds']) {
-            list($campsiteBoost, $ids) = $this->filters['campsiteIds'];
+            [$campsiteBoost, $ids] = $this->filters['campsiteIds'];
             if (!$campsiteBoost) {
                 $queryParams['bool']['filter'][] = $this->getTermsQuery('_id', $ids);
             } else {
@@ -1089,7 +1132,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
             // recherche uniquement sur geo_division
             $nestedQuery = $this->getNestedQuery(
                 $this->fragmentFactory->division_nested_path,
-                [$this->fragmentFactory->getDivisionSearchQuery($this->language, $queryString),]
+                [$this->fragmentFactory->getDivisionSearchQuery($this->language, $queryString)]
             );
             $stringQuery[] = $nestedQuery;
             unset($subQuery);
@@ -1115,7 +1158,7 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
 
         // filtre sur la zone gps
         if ($this->filters['gpsLocation']) {
-            list($gpsLocation, $distance) = $this->filters['gpsLocation'];
+            [$gpsLocation, $distance] = $this->filters['gpsLocation'];
             if ($gpsLocation instanceof GpsLocationPoint) {
                 $nestedPath = $this->fragmentFactory->address_nested_path;
                 $subQuery = $this->getBoolQuery([
@@ -1221,6 +1264,17 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
         return $query;
     }
 
+    /**
+     * @param null $dateOpen
+     * @param null $dateClose
+     * @param bool $alwaysOpen
+     */
+    public function getPeriodQuery($dateOpen = null, $dateClose = null, bool $alwaysOpen = true)
+    {
+        $fragment =  $this->fragmentFactory->getPeriodQuery($dateOpen, $dateClose, $alwaysOpen);
+        $this->setAdditionalFilters(['term' => $fragment]);
+    }
+
     /**
      * @return \Cms\Search\Campsite\CampsiteSearchFragmentFactory
      */
